@@ -6,7 +6,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 from scikitplot import plotters
 from sklearn.model_selection import StratifiedKFold
-from sklearn.model_selection import train_test_split
 from sklearn.base import clone
 from scikitplot.plotters import plot_feature_importances
 from scikitplot.plotters import plot_learning_curve
@@ -55,7 +54,8 @@ def classifier_factory(clf):
 
 
 def plot_confusion_matrix(clf, X, y, title=None, normalize=False, do_cv=True, cv=None,
-                          shuffle=True, random_state=None, ax=None):
+                          shuffle=True, random_state=None, ax=None, figsize=None, 
+                          title_fontsize="large", text_fontsize="medium"):
     """Generates the confusion matrix for a given classifier and dataset.
 
     Args:
@@ -101,6 +101,16 @@ def plot_confusion_matrix(clf, X, y, title=None, normalize=False, do_cv=True, cv
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6). 
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes. 
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes. 
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
@@ -143,13 +153,15 @@ def plot_confusion_matrix(clf, X, y, title=None, normalize=False, do_cv=True, cv
         y_true = np.concatenate(trues_list)
 
     ax = plotters.plot_confusion_matrix(y_true=y_true, y_pred=y_pred,
-                                        title=title, normalize=normalize, ax=ax)
+                                        title=title, normalize=normalize, ax=ax, figsize=figsize, 
+                                        title_fontsize=title_fontsize, text_fontsize=text_fontsize)
 
     return ax
 
 
 def plot_roc_curve(clf, X, y, title='ROC Curves', do_cv=True, cv=None,
-                   shuffle=True, random_state=None, ax=None):
+                   shuffle=True, random_state=None, ax=None, figsize=None,
+                   title_fontsize="large", text_fontsize="medium"):
     """Generates the ROC curves for a given classifier and dataset.
 
     Args:
@@ -191,6 +203,15 @@ def plot_roc_curve(clf, X, y, title='ROC Curves', do_cv=True, cv=None,
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
@@ -236,12 +257,15 @@ def plot_roc_curve(clf, X, y, title='ROC Curves', do_cv=True, cv=None,
         y_true = np.concatenate(trues_list)
 
     # Compute ROC curve and ROC area for each class
-    ax = plotters.plot_roc_curve(y_true=y_true, y_probas=probas, title=title, ax=ax)
+    ax = plotters.plot_roc_curve(y_true=y_true, y_probas=probas, title=title, ax=ax,
+                                 figsize=figsize, title_fontsize=title_fontsize,
+                                 text_fontsize=text_fontsize)
     return ax
 
 
 def plot_ks_statistic(clf, X, y, title='KS Statistic Plot', do_cv=True, cv=None,
-                   shuffle=True, random_state=None, ax=None):
+                      shuffle=True, random_state=None, ax=None, figsize=None,
+                      title_fontsize="large", text_fontsize="medium"):
     """Generates the KS Statistic plot for a given classifier and dataset.
 
     Args:
@@ -283,6 +307,15 @@ def plot_ks_statistic(clf, X, y, title='KS Statistic Plot', do_cv=True, cv=None,
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
@@ -327,13 +360,15 @@ def plot_ks_statistic(clf, X, y, title='KS Statistic Plot', do_cv=True, cv=None,
         probas = np.concatenate(preds_list, axis=0)
         y_true = np.concatenate(trues_list)
 
-    ax = plotters.plot_ks_statistic(y_true, probas, title=title, ax=ax)
+    ax = plotters.plot_ks_statistic(y_true, probas, title=title, ax=ax, figsize=figsize,
+                                    title_fontsize=title_fontsize, text_fontsize=text_fontsize)
 
     return ax
 
 
 def plot_precision_recall_curve(clf, X, y, title='Precision-Recall Curve', do_cv=True,
-                                cv=None, shuffle=True, random_state=None, ax=None):
+                                cv=None, shuffle=True, random_state=None, ax=None,
+                                figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates the Precision-Recall curve for a given classifier and dataset.
 
     Args:
@@ -375,6 +410,15 @@ def plot_precision_recall_curve(clf, X, y, title='Precision-Recall Curve', do_cv
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
@@ -421,5 +465,7 @@ def plot_precision_recall_curve(clf, X, y, title='Precision-Recall Curve', do_cv
         y_true = np.concatenate(trues_list)
 
     # Compute Precision-Recall curve and area for each class
-    ax = plotters.plot_precision_recall_curve(y_true, probas, title=title, ax=ax)
+    ax = plotters.plot_precision_recall_curve(y_true, probas, title=title, ax=ax,
+                                              figsize=figsize, title_fontsize=title_fontsize,
+                                              text_fontsize=text_fontsize)
     return ax
