@@ -22,7 +22,8 @@ from sklearn.metrics import silhouette_samples
 from scipy.spatial.distance import cdist, pdist
 
 
-def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None):
+def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None, figsize=None, 
+                          title_fontsize="large", text_fontsize="medium"):
     """Generates confusion matrix plot for a given set of ground truth labels and classifier predictions.
 
     Args:
@@ -41,14 +42,24 @@ def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None):
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6). 
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes. 
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes. 
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+            
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
+        >>> import scikitplot.plotters as skplt
         >>> rf = RandomForestClassifier()
         >>> rf = rf.fit(X_train, y_train)
         >>> y_pred = rf.predict(X_test)
-        >>> plot_confusion_matrix(y_test, y_pred, normalize=True)
+        >>> skplt.plot_confusion_matrix(y_test, y_pred, normalize=True)
         <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
         >>> plt.show()
 
@@ -57,7 +68,7 @@ def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None):
            :alt: Confusion matrix
     """
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
     cm = confusion_matrix(y_true, y_pred)
     classes = np.unique(y_true)
@@ -67,33 +78,36 @@ def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None):
         cm = np.around(cm, decimals=2)
 
     if title:
-        ax.set_title(title)
+        ax.set_title(title, fontsize=title_fontsize)
     elif normalize:
-        ax.set_title('Normalized Confusion Matrix')
+        ax.set_title('Normalized Confusion Matrix', fontsize=title_fontsize)
     else:
-        ax.set_title('Confusion Matrix')
+        ax.set_title('Confusion Matrix', fontsize=title_fontsize)
 
     image = ax.imshow(cm, interpolation='nearest', cmap=plt.cm.Blues)
     plt.colorbar(mappable=image)
     tick_marks = np.arange(len(classes))
     ax.set_xticks(tick_marks)
-    ax.set_xticklabels(classes)
+    ax.set_xticklabels(classes, fontsize=text_fontsize)
     ax.set_yticks(tick_marks)
-    ax.set_yticklabels(classes)
+    ax.set_yticklabels(classes, fontsize=text_fontsize)
 
     thresh = cm.max() / 2.
     for i, j in itertools.product(range(cm.shape[0]), range(cm.shape[1])):
         ax.text(j, i, cm[i, j],
                 horizontalalignment="center",
+                verticalalignment="center",
+                fontsize=text_fontsize,
                 color="white" if cm[i, j] > thresh else "black")
 
-    ax.set_ylabel('True label')
-    ax.set_xlabel('Predicted label')
+    ax.set_ylabel('True label', fontsize=text_fontsize)
+    ax.set_xlabel('Predicted label', fontsize=text_fontsize)
 
     return ax
 
 
-def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None):
+def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None, figsize=None,
+                   title_fontsize="large", text_fontsize="medium"):
     """Generates the ROC curves for a set of ground truth labels and classifier probability predictions.
 
     Args:
@@ -108,14 +122,24 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None):
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
+        >>> import scikitplot.plotters as skplt
         >>> nb = GaussianNB()
         >>> nb = nb.fit(X_train, y_train)
         >>> y_probas = nb.predict_proba(X_test)
-        >>> plot_roc_curve(y_test, y_probas)
+        >>> skplt.plot_roc_curve(y_test, y_probas)
         <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
         >>> plt.show()
 
@@ -171,9 +195,9 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None):
     roc_auc[macro_key] = auc(fpr[macro_key], tpr[macro_key])
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
 
     for i in range(len(classes)):
         ax.plot(fpr[i], tpr[i], lw=2,
@@ -190,13 +214,15 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None):
     ax.plot([0, 1], [0, 1], 'k--', lw=2)
     ax.set_xlim([0.0, 1.0])
     ax.set_ylim([0.0, 1.05])
-    ax.set_xlabel('False Positive Rate')
-    ax.set_ylabel('True Positive Rate')
-    ax.legend(loc='lower right')
+    ax.set_xlabel('False Positive Rate', fontsize=text_fontsize)
+    ax.set_ylabel('True Positive Rate', fontsize=text_fontsize)
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc='lower right', fontsize=text_fontsize)
     return ax
 
 
-def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None):
+def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None, figsize=None,
+                      title_fontsize="large", text_fontsize="medium"):
     """Generates the KS Statistic plot for a set of ground truth labels and classifier probability predictions.
 
     Args:
@@ -211,14 +237,24 @@ def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None):
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
+        >>> import scikitplot.plotters as skplt
         >>> lr = LogisticRegression()
         >>> lr = lr.fit(X_train, y_train)
         >>> y_probas = lr.predict_proba(X_test)
-        >>> plot_ks_statistic(y_test, y_probas)
+        >>> skplt.plot_ks_statistic(y_test, y_probas)
         <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
         >>> plt.show()
 
@@ -237,9 +273,9 @@ def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None):
         max_distance_at, classes = binary_ks_curve(y_true, probas[:, 1].ravel())
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
 
     ax.plot(thresholds, pct1, lw=3, label='Class {}'.format(classes[0]))
     ax.plot(thresholds, pct2, lw=3, label='Class {}'.format(classes[1]))
@@ -251,14 +287,16 @@ def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None):
     ax.set_xlim([0.0, 1.0])
     ax.set_ylim([0.0, 1.0])
 
-    ax.set_xlabel('Threshold')
-    ax.set_ylabel('Percentage below threshold')
-    ax.legend(loc='lower right')
+    ax.set_xlabel('Threshold', fontsize=text_fontsize)
+    ax.set_ylabel('Percentage below threshold', fontsize=text_fontsize)
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc='lower right', fontsize=text_fontsize)
 
     return ax
 
 
-def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve', ax=None):
+def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve', ax=None,
+                                figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates the Precision Recall Curve for a set of ground truth labels and classifier probability predictions.
 
     Args:
@@ -271,14 +309,24 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
+        >>> import scikitplot.plotters as skplt
         >>> nb = GaussianNB()
         >>> nb = nb.fit(X_train, y_train)
         >>> y_probas = nb.predict_proba(X_test)
-        >>> plot_precision_recall_curve(y_test, y_probas)
+        >>> skplt.plot_precision_recall_curve(y_test, y_probas)
         <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
         >>> plt.show()
 
@@ -316,9 +364,9 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
     average_precision[micro_key] = average_precision_score(y_true, probas, average='micro')
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
     for i in range(len(classes)):
         ax.plot(recall[i], precision[i], lw=2,
                 label='Precision-recall curve of class {0} '
@@ -331,12 +379,14 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
     ax.set_ylim([0.0, 1.05])
     ax.set_xlabel('Recall')
     ax.set_ylabel('Precision')
-    ax.legend(loc='best')
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc='best', fontsize=text_fontsize)
     return ax
 
 
 def plot_feature_importances(clf, title='Feature Importance', feature_names=None,
-                             max_num_features=20, order='descending', ax=None):
+                             max_num_features=20, order='descending', ax=None,
+                             figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates a plot of a classifier's feature importances.
 
     Args:
@@ -356,16 +406,26 @@ def plot_feature_importances(clf, title='Feature Importance', feature_names=None
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
-            >>> rf = RandomForestClassifier()
-            >>> rf.fit(X, y)
-            >>> plot_feature_importances(rf, feature_names=['petal length', 'petal width',
-            ...                                             'sepal length', 'sepal width'])
-            <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
-            >>> plt.show()
+        >>> import scikitplot.plotters as skplt
+        >>> rf = RandomForestClassifier()
+        >>> rf.fit(X, y)
+        >>> skplt.plot_feature_importances(rf, feature_names=['petal length', 'petal width',
+        ...                                                   'sepal length', 'sepal width'])
+        <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
+        >>> plt.show()
 
         .. image:: _static/examples/plot_feature_importances.png
            :align: center
@@ -399,7 +459,7 @@ def plot_feature_importances(clf, title='Feature Importance', feature_names=None
         raise ValueError('Invalid argument {} for "order"'.format(order))
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
     if feature_names is None:
         feature_names = indices
@@ -408,7 +468,7 @@ def plot_feature_importances(clf, title='Feature Importance', feature_names=None
 
     max_num_features = min(max_num_features, len(importances))
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
 
     if std is not None:
         ax.bar(range(max_num_features), importances[indices][:max_num_features], color='r',
@@ -420,11 +480,12 @@ def plot_feature_importances(clf, title='Feature Importance', feature_names=None
     ax.set_xticks(range(max_num_features))
     ax.set_xticklabels(feature_names[:max_num_features])
     ax.set_xlim([-1, max_num_features])
+    ax.tick_params(labelsize=text_fontsize)
     return ax
 
 
 def plot_learning_curve(clf, X, y, title='Learning Curve', cv=None, train_sizes=None, n_jobs=1,
-                        ax=None):
+                        ax=None, figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates a plot of the train and test learning curves for a given classifier.
 
     Args:
@@ -461,12 +522,22 @@ def plot_learning_curve(clf, X, y, title='Learning Curve', cv=None, train_sizes=
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
-        >>> rf = classifier_factory(RandomForestClassifier())
-        >>> rf.plot_learning_curve(X, y)
+        >>> import scikitplot.plotters as skplt
+        >>> rf = RandomForestClassifier()
+        >>> skplt.plot_learning_curve(rf, X, y)
         <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
         >>> plt.show()
 
@@ -475,14 +546,14 @@ def plot_learning_curve(clf, X, y, title='Learning Curve', cv=None, train_sizes=
            :alt: Learning Curve
     """
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
     if train_sizes is None:
         train_sizes = np.linspace(.1, 1.0, 5)
 
-    ax.set_title(title)
-    ax.set_xlabel("Training examples")
-    ax.set_ylabel("Score")
+    ax.set_title(title, fontsize=title_fontsize)
+    ax.set_xlabel("Training examples", fontsize=text_fontsize)
+    ax.set_ylabel("Score", fontsize=text_fontsize)
     train_sizes, train_scores, test_scores = learning_curve(
         clf, X, y, cv=cv, n_jobs=n_jobs, train_sizes=train_sizes)
     train_scores_mean = np.mean(train_scores, axis=1)
@@ -498,12 +569,14 @@ def plot_learning_curve(clf, X, y, title='Learning Curve', cv=None, train_sizes=
             label="Training score")
     ax.plot(train_sizes, test_scores_mean, 'o-', color="g",
             label="Cross-validation score")
-    ax.legend(loc="best")
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc="best", fontsize=text_fontsize)
 
     return ax
 
 
-def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', copy=True, ax=None):
+def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', copy=True, ax=None,
+                    figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Plots silhouette analysis of clusters using fit_predict.
 
     Args:
@@ -526,14 +599,24 @@ def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', cop
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
-            >>> kmeans = KMeans(n_clusters=4, random_state=1)
-            >>> plot_silhouette(kmeans, X)
-            <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
-            >>> plt.show()
+        >>> import scikitplot.plotters as skplt
+        >>> kmeans = KMeans(n_clusters=4, random_state=1)
+        >>> skplt.plot_silhouette(kmeans, X)
+        <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
+        >>> plt.show()
 
         .. image:: _static/examples/plot_silhouette.png
            :align: center
@@ -551,15 +634,15 @@ def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', cop
     sample_silhouette_values = silhouette_samples(X, cluster_labels, metric=metric)
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
     ax.set_xlim([-0.1, 1])
 
     ax.set_ylim([0, len(X) + (n_clusters + 1) * 10 + 10])
 
-    ax.set_xlabel('Silhouette coefficient values')
-    ax.set_ylabel('Cluster label')
+    ax.set_xlabel('Silhouette coefficient values', fontsize=text_fontsize)
+    ax.set_ylabel('Cluster label', fontsize=text_fontsize)
 
     y_lower = 10
 
@@ -577,7 +660,7 @@ def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', cop
                          0, ith_cluster_silhouette_values,
                          facecolor=color, edgecolor=color, alpha=0.7)
 
-        ax.text(-0.05, y_lower + 0.5 * size_cluster_i, str(i))
+        ax.text(-0.05, y_lower + 0.5 * size_cluster_i, str(i), fontsize=text_fontsize)
 
         y_lower = y_upper + 10
 
@@ -587,12 +670,14 @@ def plot_silhouette(clf, X, title='Silhouette Analysis', metric='euclidean', cop
     ax.set_yticks([])  # Clear the y-axis labels / ticks
     ax.set_xticks(np.arange(-0.1, 1.0, 0.2))
 
-    ax.legend(loc='best')
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc='best', fontsize=text_fontsize)
 
     return ax
 
 
-def plot_elbow_curve(clf, X, title='Elbow Plot', cluster_ranges=None, ax=None):
+def plot_elbow_curve(clf, X, title='Elbow Plot', cluster_ranges=None, ax=None,
+                     figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Plots elbow curve of different values of K for KMeans clustering.
 
     Args:
@@ -614,14 +699,24 @@ def plot_elbow_curve(clf, X, title='Elbow Plot', cluster_ranges=None, ax=None):
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
     Returns:
         ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
 
     Example:
-            >>> kmeans = KMeans(random_state=1)
-            >>> plot_elbow_curve(kmeans, cluster_ranges=range(1, 11))
-            <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
-            >>> plt.show()
+        >>> import scikitplot.plotters as skplt
+        >>> kmeans = KMeans(random_state=1)
+        >>> skplt.plot_elbow_curve(kmeans, cluster_ranges=range(1, 11))
+        <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
+        >>> plt.show()
 
         .. image:: _static/examples/plot_elbow_curve.png
            :align: center
@@ -653,12 +748,150 @@ def plot_elbow_curve(clf, X, title='Elbow Plot', cluster_ranges=None, ax=None):
     bss = tss - wcss
 
     if ax is None:
-        fig, ax = plt.subplots(1, 1)
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
 
-    ax.set_title(title)
+    ax.set_title(title, fontsize=title_fontsize)
     ax.plot(cluster_ranges, bss/tss*100, 'b*-')
     ax.grid(True)
-    ax.set_xlabel('Number of clusters')
-    ax.set_ylabel('Percent variance explained')
+    ax.set_xlabel('Number of clusters', fontsize=text_fontsize)
+    ax.set_ylabel('Percent variance explained', fontsize=text_fontsize)
+    ax.tick_params(labelsize=text_fontsize)
+
+    return ax
+
+
+def plot_pca_component_variance(clf, title='PCA Component Explained Variances',
+                                target_explained_variance=0.75, ax=None, figsize=None,
+                                title_fontsize="large", text_fontsize="medium"):
+    """Plots PCA components' explained variance ratios. (new in v0.2.2)
+
+    Args:
+        clf: PCA instance that has the ``explained_variance_ratio_`` attribute.
+
+        title (string, optional): Title of the generated plot. Defaults to "PCA Component
+            Explained Variances"
+
+        target_explained_variance (float, optional): Looks for the minimum number of
+            principal components that satisfies this value and emphasizes it on the plot.
+            Defaults to 0.75.4
+
+        ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
+            the learning curve. If None, the plot is drawn on a new set of axes.
+
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
+    Returns:
+        ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
+
+    Example:
+        >>> import scikitplot.plotters as skplt
+        >>> pca = PCA(random_state=1)
+        >>> pca.fit(X)
+        >>> skplt.plot_pca_component_variance(pca)
+        <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
+        >>> plt.show()
+
+        .. image:: _static/examples/plot_pca_component_variance.png
+           :align: center
+           :alt: PCA Component variances
+    """
+    if not hasattr(clf, 'explained_variance_ratio_'):
+        raise TypeError('"clf" does not have explained_variance_ratio_ '
+                        'attribute. Has the PCA been fitted?')
+
+    if ax is None:
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
+
+    ax.set_title(title, fontsize=title_fontsize)
+
+    cumulative_sum_ratios = np.cumsum(clf.explained_variance_ratio_)
+
+    # Magic code for figuring out closest value to target_explained_variance
+    idx = np.searchsorted(cumulative_sum_ratios, target_explained_variance)
+
+    ax.plot(range(len(clf.explained_variance_ratio_) + 1),
+            np.concatenate(([0], np.cumsum(clf.explained_variance_ratio_))), '*-')
+    ax.grid(True)
+    ax.set_xlabel('First n principal components', fontsize=text_fontsize)
+    ax.set_ylabel('Explained variance ratio of first n components', fontsize=text_fontsize)
+    ax.set_ylim([-0.02, 1.02])
+    if idx < len(cumulative_sum_ratios):
+        ax.plot(idx+1, cumulative_sum_ratios[idx], 'ro',
+                label='{0:0.3f} Explained variance ratio for '
+                'first {1} components'.format(cumulative_sum_ratios[idx], idx+1),
+                markersize=4, markeredgewidth=4)
+        ax.axhline(cumulative_sum_ratios[idx],
+                   linestyle=':', lw=3, color='black')
+    ax.tick_params(labelsize=text_fontsize)
+    ax.legend(loc="best", fontsize=text_fontsize)
+
+    return ax
+
+
+def plot_pca_2d_projection(clf, X, y, title='PCA 2-D Projection', ax=None, figsize=None,
+                                title_fontsize="large", text_fontsize="medium"):
+    """Plots the 2-dimensional projection of PCA on a given dataset. (new in v0.2.2)
+
+    Args:
+        clf: PCA instance that can ``transform`` given data set into 2 dimensions.
+
+        X (array-like, shape (n_samples, n_features)):
+            Feature set to project, where n_samples is the number of samples and
+            n_features is the number of features.
+
+        y (array-like, shape (n_samples) or (n_samples, n_features)):
+            Target relative to X for labeling.
+
+        title (string, optional): Title of the generated plot. Defaults to "PCA 2-D
+            Projection"
+
+        ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
+            the learning curve. If None, the plot is drawn on a new set of axes.
+
+        figsize (2-tuple, optional): Tuple denoting figure size of the plot e.g. (6, 6).
+            Defaults to ``None``.
+
+        title_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "large".
+
+        text_fontsize (string or int, optional): Matplotlib-style fontsizes.
+            Use e.g. "small", "medium", "large" or integer-values. Defaults to "medium".
+
+    Returns:
+        ax (:class:`matplotlib.axes.Axes`): The axes on which the plot was drawn.
+
+    Example:
+        >>> import scikitplot.plotters as skplt
+        >>> pca = PCA(random_state=1)
+        >>> pca.fit(X)
+        >>> skplt.plot_pca_2d_projection(pca, X, y)
+        <matplotlib.axes._subplots.AxesSubplot object at 0x7fe967d64490>
+        >>> plt.show()
+
+        .. image:: _static/examples/plot_pca_2d_projection.png
+           :align: center
+           :alt: PCA 2D Projection
+    """
+    transformed_X = clf.transform(X)
+    if ax is None:
+        fig, ax = plt.subplots(1, 1, figsize=figsize)
+
+    ax.set_title(title, fontsize=title_fontsize)
+    classes = np.unique(np.array(y))
+
+    for label in classes:
+        ax.scatter(transformed_X[y == label, 0], transformed_X[y == label, 1],
+                   alpha=0.8, lw=2, label=label)
+    ax.legend(loc='best', shadow=False, scatterpoints=1, fontsize=text_fontsize)
+    ax.set_xlabel('First Principal Component', fontsize=text_fontsize)
+    ax.set_ylabel('Second Principal Component', fontsize=text_fontsize)
+    ax.tick_params(labelsize=text_fontsize)
 
     return ax
